/// <reference types="@project-serum/anchor/node_modules/@solana/web3.js" />
import { Transaction, TransactionInstruction, Signer, ConfirmOptions, Connection } from '@solana/web3.js';
import { AnchorProvider } from '@project-serum/anchor';
import { FaucetClient } from './faucet';
import type { Cypher } from '../generated/types/cypher';
import type { Cluster, Wallet } from '../types';
export declare class CypherClient {
    readonly cluster: Cluster;
    private _program;
    faucet: FaucetClient;
    constructor(cluster: Cluster, rpcEndpoint: string, wallet?: Wallet, confirmOpts?: ConfirmOptions);
    connectWallet(wallet: Wallet, rpcEndpoint: string, confirmOpts?: ConfirmOptions): void;
    private get _provider();
    get anchorProvider(): AnchorProvider;
    get connection(): Connection;
    get methods(): import("@project-serum/anchor").MethodsNamespace<Cypher, {
        name: "cacheOraclePrices";
        accounts: [{
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "cacheIndex";
            type: "u64";
        }];
    } | {
        name: "claimIdoProceeds";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "destinationTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "idoAuthority";
            isMut: true;
            isSigner: true;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "claimLiquidityMiningRewards";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "destinationTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "idoAuthority";
            isMut: true;
            isSigner: true;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "closeAccount";
        accounts: [{
            name: "account";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closeCacheAccount";
        accounts: [{
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closeClearing";
        accounts: [{
            name: "clearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closeFuturesMarket";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "priceHistory";
            isMut: true;
            isSigner: false;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closeOracleProducts";
        accounts: [{
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closeOrdersAccount";
        accounts: [{
            name: "masterAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: false;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closePerpMarket";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "closePool";
        accounts: [{
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "closePoolNode";
        accounts: [{
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "closeSubAccount";
        accounts: [{
            name: "account";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "rentDestination";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "createAccount";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "accountNumber";
            type: "u8";
        }, {
            name: "accountBump";
            type: "u8";
        }];
    } | {
        name: "createPublicClearing";
        accounts: [{
            name: "clearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CreateClearingArgs";
            };
        }];
    } | {
        name: "createPrivateClearing";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "privateClearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CreateClearingArgs";
            };
        }];
    } | {
        name: "createOrdersAccount";
        accounts: [{
            name: "masterAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: false;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "createFuturesMarket";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "priceHistory";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePool";
            isMut: false;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CreateFuturesMarketArgs";
            };
        }];
    } | {
        name: "createPerpMarket";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePool";
            isMut: false;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CreatePerpetualMarketArgs";
            };
        }];
    } | {
        name: "createPool";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "dexMarket";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CreatePoolArgs";
            };
        }];
    } | {
        name: "createPoolNode";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "vaultSignerBump";
            type: "u8";
        }, {
            name: "nodeNumber";
            type: "u8";
        }];
    } | {
        name: "createSubAccount";
        accounts: [{
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "subAccountNumber";
            type: "u8";
        }, {
            name: "subAccountBump";
            type: "u8";
        }, {
            name: "subAccountAlias";
            type: {
                array: ["u8", 32];
            };
        }];
    } | {
        name: "createWhitelist";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "whitelist";
            isMut: true;
            isSigner: false;
        }, {
            name: "accountOwner";
            isMut: false;
            isSigner: false;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "createWhitelistedAccount";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "whitelist";
            isMut: true;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "accountNumber";
            type: "u8";
        }, {
            name: "accountBump";
            type: "u8";
        }];
    } | {
        name: "depositDeliverable";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "sourceTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "amount";
            type: "u64";
        }];
    } | {
        name: "depositFunds";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "sourceTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "amount";
            type: "u64";
        }];
    } | {
        name: "editSubAccountMargining";
        accounts: [{
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "marginingType";
            type: {
                defined: "SubAccountMargining";
            };
        }];
    } | {
        name: "createOracleProducts";
        accounts: [{
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CreateOracleProductsArgs";
            };
        }];
    } | {
        name: "initCacheAccount";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "liquidateFuturesPosition";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqorClearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqorAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqorSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqeeClearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqeeAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqeeSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "asset";
            type: "publicKey";
        }, {
            name: "liability";
            type: "publicKey";
        }];
    } | {
        name: "liquidatePerpPosition";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqorClearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqorAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqorSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqeeClearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqeeAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqeeSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "asset";
            type: "publicKey";
        }, {
            name: "liability";
            type: "publicKey";
        }];
    } | {
        name: "liquidateSpotPosition";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqorClearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqorAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqorSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqeeClearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "liqeeAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "liqeeSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "assetPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "liabilityMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "liabilityPool";
            isMut: true;
            isSigner: false;
        }, {
            name: "liabilityPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "rollMarketExpiry";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "expirationTs";
            type: "u64";
        }];
    } | {
        name: "setAccountDelegate";
        accounts: [{
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }, {
            name: "delegate";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "setClearingAuthority";
        accounts: [{
            name: "clearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "newAuthority";
            type: "publicKey";
        }];
    } | {
        name: "setClearingFeeTiers";
        accounts: [{
            name: "clearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "feeTiers";
            type: {
                vec: {
                    defined: "FeeTierArgs";
                };
            };
        }];
    } | {
        name: "setClearingFeeMint";
        accounts: [{
            name: "clearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "feeMint";
            type: "publicKey";
        }];
    } | {
        name: "setFuturesMarketAuthority";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "newAuthority";
            type: "publicKey";
        }];
    } | {
        name: "setFuturesMarketLiquidityMiningInfo";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "args";
            type: {
                defined: "LiquidityMiningArgs";
            };
        }];
    } | {
        name: "setFuturesMarketParams";
        accounts: [{
            name: "cache";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "maxBaseOrderSize";
            type: {
                option: "u64";
            };
        }, {
            name: "maxQuoteOrderSize";
            type: {
                option: "u64";
            };
        }, {
            name: "initAssetWeight";
            type: {
                option: "u8";
            };
        }, {
            name: "maintAssetWeight";
            type: {
                option: "u8";
            };
        }, {
            name: "initLiabWeight";
            type: {
                option: "u8";
            };
        }, {
            name: "maintLiabWeight";
            type: {
                option: "u8";
            };
        }];
    } | {
        name: "setFuturesMarketStatus";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "status";
            type: {
                defined: "OperatingStatus";
            };
        }];
    } | {
        name: "setPerpetualMarketAuthority";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "newAuthority";
            type: "publicKey";
        }];
    } | {
        name: "setPerpetualMarketLiquidityMiningInfo";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "args";
            type: {
                defined: "LiquidityMiningArgs";
            };
        }];
    } | {
        name: "setPerpetualMarketParams";
        accounts: [{
            name: "cache";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "impactQuantity";
            type: {
                option: "u64";
            };
        }, {
            name: "maxBaseOrderSize";
            type: {
                option: "u64";
            };
        }, {
            name: "maxQuoteOrderSize";
            type: {
                option: "u64";
            };
        }, {
            name: "initAssetWeight";
            type: {
                option: "u8";
            };
        }, {
            name: "maintAssetWeight";
            type: {
                option: "u8";
            };
        }, {
            name: "initLiabWeight";
            type: {
                option: "u8";
            };
        }, {
            name: "maintLiabWeight";
            type: {
                option: "u8";
            };
        }];
    } | {
        name: "setPerpetualMarketStatus";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "status";
            type: {
                defined: "OperatingStatus";
            };
        }];
    } | {
        name: "setPoolNodeStatus";
        accounts: [{
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "status";
            type: {
                defined: "OperatingStatus";
            };
        }];
    } | {
        name: "setPoolStatus";
        accounts: [{
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "status";
            type: {
                defined: "OperatingStatus";
            };
        }];
    } | {
        name: "setOracleProducts";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "oracleProducts";
            isMut: true;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "setSubAccountDelegate";
        accounts: [{
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }, {
            name: "delegate";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "setPoolDexMarket";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "dexMarket";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "settlePositionWithDelivery";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "underlyingPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "settlePosition";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "sweepMarketFees";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "destinationTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "sweepPoolFees";
        accounts: [{
            name: "tokenPool";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "destinationTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "transferBetweenSubAccounts";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "fromSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "toSubAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "assetPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "amount";
            type: "u64";
        }];
    } | {
        name: "updateAccountMargin";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "signer";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "updateFundingRate";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: false;
            isSigner: false;
        }, {
            name: "bids";
            isMut: false;
            isSigner: false;
        }, {
            name: "asks";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "updateMarketExpiration";
        accounts: [{
            name: "clearing";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }];
        args: [{
            name: "expirationTs";
            type: "u64";
        }];
    } | {
        name: "updateTokenIndex";
        accounts: [{
            name: "cacheAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "withdrawFunds";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "poolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "destinationTokenAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "amount";
            type: "u64";
        }];
    } | {
        name: "cancelSpotOrder";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "assetVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "dex";
            accounts: [{
                name: "market";
                isMut: true;
                isSigner: false;
            }, {
                name: "openOrders";
                isMut: true;
                isSigner: false;
            }, {
                name: "eventQueue";
                isMut: true;
                isSigner: false;
            }, {
                name: "bids";
                isMut: true;
                isSigner: false;
            }, {
                name: "asks";
                isMut: true;
                isSigner: false;
            }, {
                name: "coinVault";
                isMut: true;
                isSigner: false;
            }, {
                name: "pcVault";
                isMut: true;
                isSigner: false;
            }, {
                name: "vaultSigner";
                isMut: true;
                isSigner: false;
            }, {
                name: "tokenProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "dexProgram";
                isMut: false;
                isSigner: false;
            }];
        }];
        args: [{
            name: "args";
            type: {
                defined: "CancelOrderArgs";
            };
        }];
    } | {
        name: "closeSpotOpenOrders";
        accounts: [{
            name: "masterAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "assetPool";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "dexMarket";
            isMut: false;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }, {
            name: "dexProgram";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "initSpotOpenOrders";
        accounts: [{
            name: "masterAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "pool";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "dexMarket";
            isMut: false;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "dexProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "newSpotOrder";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "assetVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "dex";
            accounts: [{
                name: "market";
                isMut: true;
                isSigner: false;
            }, {
                name: "openOrders";
                isMut: true;
                isSigner: false;
            }, {
                name: "eventQueue";
                isMut: true;
                isSigner: false;
            }, {
                name: "requestQueue";
                isMut: true;
                isSigner: false;
            }, {
                name: "bids";
                isMut: true;
                isSigner: false;
            }, {
                name: "asks";
                isMut: true;
                isSigner: false;
            }, {
                name: "coinVault";
                isMut: true;
                isSigner: false;
            }, {
                name: "pcVault";
                isMut: true;
                isSigner: false;
            }, {
                name: "vaultSigner";
                isMut: true;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "dexProgram";
                isMut: false;
                isSigner: false;
            }];
        }];
        args: [{
            name: "args";
            type: {
                defined: "NewSpotOrderArgs";
            };
        }];
    } | {
        name: "settleSpotFunds";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetPoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "assetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "assetVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "quoteVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "dex";
            accounts: [{
                name: "market";
                isMut: true;
                isSigner: false;
            }, {
                name: "openOrders";
                isMut: true;
                isSigner: false;
            }, {
                name: "coinVault";
                isMut: true;
                isSigner: false;
            }, {
                name: "pcVault";
                isMut: true;
                isSigner: false;
            }, {
                name: "vaultSigner";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "dexProgram";
                isMut: false;
                isSigner: false;
            }];
        }];
        args: [];
    } | {
        name: "cancelFuturesOrder";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CancelOrderArgs";
            };
        }];
    } | {
        name: "consumeFuturesEvents";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: false;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }];
        args: [{
            name: "limit";
            type: "u16";
        }];
    } | {
        name: "newFuturesOrder";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "priceHistory";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "args";
            type: {
                defined: "NewDerivativeOrderArgs";
            };
        }];
    } | {
        name: "pruneFuturesOrders";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "limit";
            type: "u8";
        }];
    } | {
        name: "settleFuturesFunds";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [];
    } | {
        name: "cancelPerpOrder";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "args";
            type: {
                defined: "CancelOrderArgs";
            };
        }];
    } | {
        name: "consumePerpEvents";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: false;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }];
        args: [{
            name: "limit";
            type: "u16";
        }];
    } | {
        name: "newPerpOrder";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "args";
            type: {
                defined: "NewDerivativeOrderArgs";
            };
        }];
    } | {
        name: "prunePerpOrders";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "orderbook";
            isMut: true;
            isSigner: false;
        }, {
            name: "eventQueue";
            isMut: true;
            isSigner: false;
        }, {
            name: "bids";
            isMut: true;
            isSigner: false;
        }, {
            name: "asks";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }, {
            name: "authority";
            isMut: true;
            isSigner: true;
        }];
        args: [{
            name: "limit";
            type: "u8";
        }];
    } | {
        name: "settlePerpFunds";
        accounts: [{
            name: "clearing";
            isMut: false;
            isSigner: false;
        }, {
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }];
        args: [];
    } | {
        name: "settleFunding";
        accounts: [{
            name: "cacheAccount";
            isMut: false;
            isSigner: false;
        }, {
            name: "masterAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "subAccount";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: false;
            isSigner: false;
        }, {
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "quotePoolNode";
            isMut: true;
            isSigner: false;
        }];
        args: [];
    }>;
    get accounts(): import("@project-serum/anchor").AccountNamespace<Cypher>;
    get isWalletConnected(): boolean;
    get walletPubkey(): import("@solana/web3.js").PublicKey;
    get cypherPID(): import("@solana/web3.js").PublicKey;
    get dexPID(): import("@solana/web3.js").PublicKey;
    get quoteMint(): import("@solana/web3.js").PublicKey;
    addEventListener(eventName: string, callback: (event: any, slot: number) => void): number;
    removeEventListener(listener: number): Promise<void>;
    sendAndConfirm(tx: Transaction, signers?: Signer[], opts?: ConfirmOptions): Promise<string>;
    sendAndConfirmIxs(ixs: TransactionInstruction[], signers?: Signer[], opts?: ConfirmOptions): Promise<string>;
}
